You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by pm...@apache.org on 2017/11/21 20:08:52 UTC

svn commit: r1815979 - in /jmeter/trunk/src: core/org/apache/jmeter/gui/util/ core/org/apache/jmeter/testelement/ protocol/http/org/apache/jmeter/protocol/http/control/ protocol/http/org/apache/jmeter/protocol/http/proxy/

Author: pmouawad
Date: Tue Nov 21 20:08:52 2017
New Revision: 1815979

URL: http://svn.apache.org/viewvc?rev=1815979&view=rev
Log:
Bug 61591 - UX : Remove Workbench
Allow moving and copying Test Script Recorder under test plan
Allow moving and copying Test Script Recorder under Test Fragment
Bugzilla Id: 61591

Added:
    jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java   (with props)
Modified:
    jmeter/trunk/src/core/org/apache/jmeter/gui/util/MenuFactory.java
    jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/control/HttpMirrorServer.java
    jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java

Modified: jmeter/trunk/src/core/org/apache/jmeter/gui/util/MenuFactory.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/gui/util/MenuFactory.java?rev=1815979&r1=1815978&r2=1815979&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java (added)
+++ jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java Tue Nov 21 20:08:52 2017
@@ -0,0 +1,25 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.jmeter.testelement;
+
+/**
+ * Identify Non Test Elements
+ */
+public interface NonTestElement {
+
+}

Propchange: jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/control/HttpMirrorServer.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/control/HttpMirrorServer.java?rev=1815979&r1=1815978&r2=1815979&view=diff
==============================================================================
--- jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/control/HttpMirrorServer.java (original)
+++ jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/control/HttpMirrorServer.java Tue Nov 21 20:08:52 2017
@@ -31,6 +31,7 @@ import org.apache.commons.cli.avalon.CLO
 import org.apache.commons.cli.avalon.CLOptionDescriptor;
 import org.apache.commons.cli.avalon.CLUtil;
 import org.apache.jmeter.gui.Stoppable;
+import org.apache.jmeter.testelement.NonTestElement;
 import org.apache.jorphan.util.JOrphanUtils;
 import org.apache.logging.log4j.Level;
 import org.apache.logging.log4j.core.config.Configurator;
@@ -43,7 +44,7 @@ import org.slf4j.LoggerFactory;
  * For each client request, creates a thread to handle the request.
  *
  */
-public class HttpMirrorServer extends Thread implements Stoppable {
+public class HttpMirrorServer extends Thread implements Stoppable, NonTestElement {
 
     private static final int OPTIONS_OPT        = '?';// $NON-NLS-1$
     private static final int PORT_OPT           = 'P';// $NON-NLS-1$

Modified: jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java?rev=1815979&r1=1815978&r2=1815979&view=diff
==============================================================================
--- jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java (original)
+++ jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java Tue Nov 21 20:08:52 2017
@@ -80,6 +80,7 @@ import org.apache.jmeter.protocol.http.u
 import org.apache.jmeter.samplers.SampleEvent;
 import org.apache.jmeter.samplers.SampleListener;
 import org.apache.jmeter.samplers.SampleResult;
+import org.apache.jmeter.testelement.NonTestElement;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.testelement.TestPlan;
 import org.apache.jmeter.testelement.TestStateListener;
@@ -107,7 +108,7 @@ import org.slf4j.LoggerFactory;
  * Class handles storing of generated samples, etc
  * For unit tests, see TestProxyControl
  */
-public class ProxyControl extends GenericController {
+public class ProxyControl extends GenericController implements NonTestElement {
 
     private static final Logger log = LoggerFactory.getLogger(ProxyControl.class);
--- jmeter/trunk/src/core/org/apache/jmeter/gui/util/MenuFactory.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/gui/util/MenuFactory.java Tue Nov 21 20:08:52 2017
@@ -49,10 +49,10 @@ import org.apache.jmeter.gui.action.Acti
 import org.apache.jmeter.gui.action.ActionRouter;
 import org.apache.jmeter.gui.action.KeyStrokes;
 import org.apache.jmeter.gui.tree.JMeterTreeNode;
-import org.apache.jmeter.protocol.http.proxy.ProxyControl;
 import org.apache.jmeter.samplers.Sampler;
 import org.apache.jmeter.testbeans.TestBean;
 import org.apache.jmeter.testbeans.gui.TestBeanGUI;
+import org.apache.jmeter.testelement.NonTestElement;
 import org.apache.jmeter.testelement.TestElement;
 import org.apache.jmeter.testelement.TestPlan;
 import org.apache.jmeter.util.JMeterUtils;
@@ -640,8 +640,8 @@ public final class MenuFactory {
             if (foundClass(nodes,
                      new Class[]{Sampler.class, Controller.class}, // Samplers and Controllers need not apply ...
                      new Class[]{org.apache.jmeter.threads.AbstractThreadGroup.class,
-                             ProxyControl.class
-                     })  // but AbstractThreadGroup (Controller) and ProxyControl are OK
+                             NonTestElement.class
+                     })  // but AbstractThreadGroup (Controller) and Non Test Elements are OK
                 ){
                 return false;
             }

Added: jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/testelement/NonTestElement.java?rev=1815979&view=auto
==============================================================================